==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/ja.js <==
/**
 * Japanese
 */

$.Editable.LANGS['ja'] = {
  translation: {
    "Bold": "\u592a\u5b57",
    "Italic": "\u659c\u4f53",
    "Underline": "\u4e0b\u7dda",
    "Strikethrough": "\u53d6\u308a\u6d88\u3057\u7dda",
    "Font Size": "\u30d5\u30a9\u30f3\u30c8\u30b5\u30a4\u30ba",
    "Color": "\u30ab\u30e9\u30fc",
    "Background Color": "\u80cc\u666f\u8272",
    "Text Color": "\u6587\u5b57\u306e\u8272",
    "Format Block": "\u66f8\u5f0f",
    "Normal": "\u30ce\u30fc\u30de\u30eb",
    "Paragraph": "\u6bb5\u843d",
    "Code": "\u30b3\u30fc\u30c9",
    "Quote": "\u5f15\u7528",
    "Heading 1": "\u30d8\u30c3\u30c0\u30fc 1",
    "Heading 2": "\u30d8\u30c3\u30c0\u30fc 2",
    "Heading 3": "\u30d8\u30c3\u30c0\u30fc 3",
    "Heading 4": "\u30d8\u30c3\u30c0\u30fc 4",
    "Heading 5": "\u30d8\u30c3\u30c0\u30fc 5",
    "Heading 6": "\u30d8\u30c3\u30c0\u30fc 6",
    "Alignment": "\u914d\u7f6e",
    "Align Left": "\u5de6\u5bc4\u305b",
    "Align Center": "\u4e2d\u592e\u63c3\u3048",
    "Align Right": "\u53f3\u5bc4\u305b",
    "Justify": "\u4e21\u7aef\u63c3\u3048",
    "Numbered List": "\u756a\u53f7\u4ed8\u304d\u7b87\u6761\u66f8\u304d",
    "Bulleted List": "\u7b87\u6761\u66f8\u304d",
    "Indent Less": "\u30a4\u30f3\u30c7\u30f3\u30c8\u3092\u6e1b\u3089\u3059",
    "Indent More": "\u30a4\u30f3\u30c7\u30f3\u30c8\u3092\u5897\u3084\u3059",
    "Select All": "\u5168\u3066\u3092\u9078\u629e",
    "Insert Link": "\u30ea\u30f3\u30af",
    "Insert Image": "\u753b\u50cf\u306e\u633f\u5165",
    "Insert Video": "\u52d5\u753b",
    "Undo": "\u5143\u306b\u623b\u3059",
    "Redo": "\u3084\u308a\u76f4\u3059",
    "Show HTML": "\u8868\u793a\u3059\u308b HTML",
    "Float Left": "\u5de6\u5bc4\u305b",
    "Float None": "\u306a\u3057",
    "Float Right": "\u53f3\u5bc4\u305b",
    "Replace Image": "\u753b\u50cf\u3092\u4ea4\u63db\u3057\u3066\u304f\u3060\u3055\u3044",
    "Remove Image": "\u753b\u50cf\u3092\u524a\u9664",
    "Title": "\u30bf\u30a4\u30c8\u30eb",
    "Insert image": "\u753b\u50cf\u306e\u633f\u5165",
    "Drop image": "\u753b\u50cf\u3092\u30c9\u30ed\u30c3\u30d7",
    "or click": "\u307e\u305f\u306f\u30af\u30ea\u30c3\u30af",
    "Enter URL": "URL\u3092\u5165\u529b\u3057\u3066\u304f\u3060\u3055\u3044",
    "Please wait!": "\u304a\u5f85\u3061\u304f\u3060\u3055\u3044!",
    "Are you sure? Image will be deleted.": "\u672c\u5f53\u306b? \u753b\u50cf\u306f\u524a\u9664\u3055\u308c\u307e\u3059\u3002",
    "UNLINK": "\u30ea\u30f3\u30af\u306e\u524a\u9664",
    "Open in new tab": "\u65b0\u3057\u3044\u30bf\u30d6\u3067\u958b\u304f",
    "Type something": "\u4f55\u304b\u5165\u529b",
    "Cancel": "\u30ad\u30e3\u30f3\u30bb\u30eb",
    "OK": "OK",
    "Manage images": "\u30a4\u30e1\u30fc\u30b8\u3092\u7ba1\u7406\u3059\u308b",
    "Delete": "\u524a\u9664",
    "Font Family": "\u30d5\u30a9\u30f3\u30c8\u30d5\u30a1\u30df\u30ea\u30fc",
    "Insert Horizontal Line": "\u6c34\u5e73\u7dda\u3092\u633f\u5165\u3057\u307e\u3059"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.3.tar.gz: django-froala-editor-0.8.3/froala_editor/static/froala_editor/js/langs/ja.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Japanese
 */

$.Editable.LANGS['ja'] = {
  translation: {
    "Bold": "\u592a\u5b57",
    "Italic": "\u659c\u4f53",
    "Underline": "\u4e0b\u7dda",
    "Strikethrough": "\u53d6\u308a\u6d88\u3057\u7dda",
    "Font Size": "\u30d5\u30a9\u30f3\u30c8\u30b5\u30a4\u30ba",
    "Color": "\u30ab\u30e9\u30fc",
    "Background Color": "\u80cc\u666f\u8272",
    "Text Color": "\u6587\u5b57\u306e\u8272",
    "Format Block": "\u66f8\u5f0f",
    "Normal": "\u30ce\u30fc\u30de\u30eb",
    "Paragraph": "\u6bb5\u843d",
    "Code": "\u30b3\u30fc\u30c9",
    "Quote": "\u5f15\u7528",
    "Heading 1": "\u30d8\u30c3\u30c0\u30fc 1",
    "Heading 2": "\u30d8\u30c3\u30c0\u30fc 2",
    "Heading 3": "\u30d8\u30c3\u30c0\u30fc 3",
    "Heading 4": "\u30d8\u30c3\u30c0\u30fc 4",
    "Heading 5": "\u30d8\u30c3\u30c0\u30fc 5",
    "Heading 6": "\u30d8\u30c3\u30c0\u30fc 6",
    "Alignment": "\u914d\u7f6e",
    "Align Left": "\u5de6\u5bc4\u305b",
    "Align Center": "\u4e2d\u592e\u63c3\u3048",
    "Align Right": "\u53f3\u5bc4\u305b",
    "Justify": "\u4e21\u7aef\u63c3\u3048",
    "Numbered List": "\u756a\u53f7\u4ed8\u304d\u7b87\u6761\u66f8\u304d",
    "Bulleted List": "\u7b87\u6761\u66f8\u304d",
    "Indent Less": "\u30a4\u30f3\u30c7\u30f3\u30c8\u3092\u6e1b\u3089\u3059",
    "Indent More": "\u30a4\u30f3\u30c7\u30f3\u30c8\u3092\u5897\u3084\u3059",
    "Select All": "\u5168\u3066\u3092\u9078\u629e",
    "Insert Link": "\u30ea\u30f3\u30af",
    "Insert Image": "\u753b\u50cf\u306e\u633f\u5165",
    "Insert Video": "\u52d5\u753b",
    "Undo": "\u5143\u306b\u623b\u3059",
    "Redo": "\u3084\u308a\u76f4\u3059",
    "Show HTML": "\u8868\u793a\u3059\u308b HTML",
    "Float Left": "\u5de6\u5bc4\u305b",
    "Float None": "\u306a\u3057",
    "Float Right": "\u53f3\u5bc4\u305b",
    "Replace Image": "\u753b\u50cf\u3092\u4ea4\u63db\u3057\u3066\u304f\u3060\u3055\u3044",
    "Remove Image": "\u753b\u50cf\u3092\u524a\u9664",
    "Title": "\u30bf\u30a4\u30c8\u30eb",
    "Insert image": "\u753b\u50cf\u306e\u633f\u5165",
    "Drop image": "\u753b\u50cf\u3092\u30c9\u30ed\u30c3\u30d7",
    "or click": "\u307e\u305f\u306f\u30af\u30ea\u30c3\u30af",
    "Enter URL": "URL\u3092\u5165\u529b\u3057\u3066\u304f\u3060\u3055\u3044",
    "Please wait!": "\u304a\u5f85\u3061\u304f\u3060\u3055\u3044!",
    "Are you sure? Image will be deleted.": "\u672c\u5f53\u306b? \u753b\u50cf\u306f\u524a\u9664\u3055\u308c\u307e\u3059\u3002",
    "UNLINK": "\u30ea\u30f3\u30af\u306e\u524a\u9664",
    "Open in new tab": "\u65b0\u3057\u3044\u30bf\u30d6\u3067\u958b\u304f",
    "Type something": "\u4f55\u304b\u5165\u529b",
    "Cancel": "\u30ad\u30e3\u30f3\u30bb\u30eb",
    "OK": "OK",
    "Manage images": "\u30a4\u30e1\u30fc\u30b8\u3092\u7ba1\u7406\u3059\u308b",
    "Delete": "\u524a\u9664",
    "Font Family": "\u30d5\u30a9\u30f3\u30c8\u30d5\u30a1\u30df\u30ea\u30fc",
    "Insert Horizontal Line": "\u6c34\u5e73\u7dda\u3092\u633f\u5165\u3057\u307e\u3059",
    "Table": "\u8868",
    "Insert table": "\u8868\u306e\u633f\u5165",
    "Cell": "\u30bb\u30eb",
    "Row": "\u884c",
    "Column": "\u5217",
    "Delete table": "\u8868\u306e\u524a\u9664",
    "Insert cell before": "\u524d\u306b\u30bb\u30eb\u3092\u633f\u5165",
    "Insert cell after": "\u5f8c\u306b\u30bb\u30eb\u3092\u633f\u5165",
    "Delete cell": "\u30bb\u30eb\u3092\u524a\u9664\u3059\u308b",
    "Merge cells": "\u30bb\u30eb\u306e\u7d50\u5408",
    "Horizontal split": "\u6c34\u5e73\u5206\u5272",
    "Vertical split": "\u5782\u76f4\u5206\u5272",
    "Insert row above": "\u4e0a\u5074\u306b\u884c\u3092\u633f\u5165",
    "Insert row below": "\u4e0b\u5074\u306b\u884c\u3092\u633f\u5165",
    "Delete row": "\u884c\u306e\u524a\u9664",
    "Insert column before": "\u5de6\u5074\u306b\u5217\u3092\u633f\u5165",
    "Insert column after": "\u53f3\u5074\u306b\u5217\u3092\u633f\u5165",
    "Delete column": "\u5217\u306e\u524a\u9664"
  },
  direction: "ltr"
};
